@@ -1,9 +1,9 @@
 /*
  * ccs_new_test.c
  *
- * Copyright (C) 2005-2011  NTT DATA CORPORATION
+ * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 1.8.3   2011/09/29
+ * Version: 1.8.3   2013/02/14
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -386,16 +386,15 @@ static void test_SYS_REBOOT(void)
 
 static void test_SYS_VHANGUP(void)
 {
-	int pty_fd = EOF;
 	int status = 0;
 	int pipe_fd[2] = { EOF, EOF };
 	int ret_ignored;
 	ret_ignored = pipe(pipe_fd);
-	switch (forkpty(&pty_fd, NULL, NULL, NULL)) {
+	switch (fork()) {
 	case 0:
+		setsid();
 		errno = 0;
 		vhangup();
-		/* Unreachable if vhangup() succeeded. */
 		status = errno;
 		ret_ignored = write(pipe_fd[1], &status, sizeof(status));
 		_exit(0);
@@ -407,7 +406,6 @@ static void test_SYS_VHANGUP(void)
 		ret_ignored = read(pipe_fd[0], &status, sizeof(status));
 		wait(NULL);
 		close(pipe_fd[0]);
-		close(pty_fd);
 	}
 	errno = status;
 	result = status ? EOF : 0;
